<?php

/*
 * This file is part of the Serenity package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace CpCreation\VitiCore\Bridge\Symfony\Bundle\Client;

use GuzzleHttp\Client;

class GeoClient extends Client
{
    public function __construct(Client $client)
    {
        parent::__construct($client->getConfig());
    }
}
