<?php

/*
 * This file is part of the VITICORE2 package.
 *
 * (c) CP Creation <web@cpcreation.fr>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace CpCreation\VitiCore\Bridge\Doctrine\Migrations;

use Doctrine\DBAL\Schema\Schema;
use Doctrine\Migrations\AbstractMigration;

final class Version20260702171500 extends AbstractMigration
{
    public function getDescription(): string
    {
        return 'Ajoute l option d affichage du menu categories de la boutique.';
    }

    public function up(Schema $schema): void
    {
        $this->addSql('ALTER TABLE shop_shop_config ADD COLUMN IF NOT EXISTS show_category_menu_front BOOLEAN DEFAULT true NOT NULL');
    }

    public function down(Schema $schema): void
    {
        $this->addSql('ALTER TABLE shop_shop_config DROP COLUMN IF EXISTS show_category_menu_front');
    }
}
