<?php

declare(strict_types=1);

namespace CpCreation\VitiCore\Bridge\Doctrine\Migrations;

use Doctrine\DBAL\Schema\Schema;
use Doctrine\Migrations\AbstractMigration;

final class Version20260507153000 extends AbstractMigration
{
    public function getDescription(): string
    {
        return 'Ajoute l état épuisé sur les options de variante produit.';
    }

    public function up(Schema $schema): void
    {
        $this->addSql('ALTER TABLE product_variant_option ADD sold_out BOOLEAN DEFAULT false NOT NULL');
    }

    public function down(Schema $schema): void
    {
        $this->addSql('ALTER TABLE product_variant_option DROP sold_out');
    }
}
